### Line Generator

This is a simple string line generator based on templates for generating logs, testing your scripts and algorithms or
other stuff if you need.

### Install

```pip install linegenerator```

### After install

Show commands:

```linegenerator-cli --help```

Show available default generators:

```linegenerator-cli --help-generators```

Install autocompletion:

```linegenerator-cli --install-completion```

Show autocompletion script:

```linegenerator-cli --show-completion```

### Examples:

```linegenerator-cli --template "Hello, {name}, wellcom to {city}!" --count 10```

output:

```
Hello, Timothy Lozano, wellcom to North Lindaberg!
Hello, Joshua Williams, wellcom to New Darrylshire!
Hello, Cody Smith, wellcom to East Kimberlyton!
```

### License

[MIT License](LICENSE)
